@@ -1,5 +1,5 @@
 /*
- * $Id: config.c 667 2005-05-24 18:26:39Z acid $
+ * $Id: config.c 875 2006-01-07 22:50:23Z jd $
  * gcc.wrapper - Wrapper for gcc used for apt-build
  * (c) 2005 - Julien Danjou <acid@debian.org>
  *
@@ -17,7 +17,7 @@
 #include "apt-build.h"
 
 char *
-parse_options (char *file_content)
+parse_options (char * file_content)
 {
   unsigned int i, j;
   char *result;
@@ -25,6 +25,10 @@ parse_options (char *file_content)
   /* Search the first " */
   for (i = 0; i <= strlen (file_content) && file_content[i] != '"'; i++);
   file_content += i + 1;
+
+  /* Remove the first spaces if they exist */
+  while (file_content[0] == ' ')
+    file_content++;
   
   /* Search the last " */
   for (j = strlen (file_content); j >= 1 && file_content[j - 1] != '"'; j--);
@@ -35,13 +39,9 @@ parse_options (char *file_content)
       exit (EXIT_FAILURE);
     }
   
-  /* Remove the first spaces if they exists */
-  while (file_content[0] == ' ')
-    file_content++;
-
   if (strlen (file_content) > 2)
     {
-      result = strndup (file_content, j - 2);
+      result = strndup (file_content, j - 1);
       return result;
     }
 
@@ -82,11 +82,8 @@ parse_conf (unsigned int argc, char **argv)
 	  if (!strncmp (opt, "Olevel", 6))
 	    args.Olevel = strdup (buf);
 
-	  if (!strncmp (opt, "march", 5))
-	    args.march = strdup (buf);
-
-	  if (!strncmp (opt, "mcpu", 4))
-	    args.mcpu = strdup (buf);
+	  if (!strncmp (opt, "mtune", 4))
+	    args.mtune = strdup (buf);
 
 	  if (!strncmp (opt, "options", 7))
 	    args.options = parse_options (file_content);
@@ -139,16 +136,16 @@ parse_conf (unsigned int argc, char **argv)
     {
       if (args.Olevel)
         cmd_line_args[nb_apt_build_options++] = args.Olevel;
-      if (args.mcpu)
-        cmd_line_args[nb_apt_build_options++] = args.mcpu;
+      if (args.mtune)
+        cmd_line_args[nb_apt_build_options++] = args.mtune;
       
 	}
 
   cmd_line_args[nb_apt_build_options++] = NULL;
 
 #if 0
- for(i = 0; i < nb_apt_build_options; i++) */
-   printf("argv[%d] -> %s\n", i, cmd_line_args[i]); */
+ for(i = 0; i < nb_apt_build_options; i++)
+   printf("argv[%d] -> %s\n", i, cmd_line_args[i]);
 #endif
 
   return cmd_line_args;
@@ -158,22 +155,14 @@ void
 filterout_libdir_path (void)
 {
   char *path;
-  char *newpath;
   char *libdir;
-  int len;
 
   /* Filter out standard apt-build search directory. */
   path = getenv ("PATH");
   if (path)
   {
-	libdir = strstr (path, LIBDIR);
-	if (libdir)
-	{
-	  len = strlen (LIBDIR);
-	  memmove (libdir, libdir + len, strlen (path) - len - (libdir - path) + 1);
-	  asprintf (&newpath, "PATH=%s", path);
-	  putenv (newpath);
-	  free (newpath);
-	}
+    libdir = strstr (path, LIBDIR);
+    if (libdir)
+      setenv ("PATH", libdir + strlen (LIBDIR) + 1, 1);
   }
 }
